--[[
Description: This plugin is part of the "Titan Panel [Currencies] Multi" addon. It shows your amount of Conquest Points.
Site: http://www.curse.com/addons/wow/titan-panel-currencies-multi
Author: Canettieri
Special Thanks to Eliote.
--]]

local ADDON_NAME, L = ...;
local version = GetAddOnMetadata(ADDON_NAME, "Version")
local ID = "TITAN_CQPSM"
local CURRENCY_ID = 390

local ICON
if UnitFactionGroup("Player") == "Alliance" then
	ICON = "Interface\\Icons\\pvpcurrency-conquest-alliance"
else
	ICON = "Interface\\Icons\\pvpcurrency-conquest-horde"
end

local currencyCount = 0.0
local currencyMaximum
local startcurrency
-----------------------------------------------
local function Util_StringComDefault(v,d)
	if not v then
		return d
	end

	return v
end
-----------------------------------------------
local eventsTable = {
	CURRENCY_DISPLAY_UPDATE = function(self)
		local name, amount, texturePath, earnedThisWeek, weeklyMax, totalMax, isDiscovered = GetCurrencyInfo(CURRENCY_ID)

		currencyCount = amount
		currencyMaximum = weeklyMax
		if not startcurrency then startcurrency = currencyCount end

		TitanPanelButton_UpdateButton(self.registry.id)
	end
}
-----------------------------------------------
local function GetButtonText(self, id)
	local currencyCountText
	if not currencyCount then
		currencyCountText = TitanUtils_GetHighlightText("0")
	elseif currencyCount > currencyMaximum * 0.4 and currencyCount < currencyMaximum * 0.59 then
		currencyCountText = "|cFF69FF69"..currencyCount
	elseif currencyCount > currencyMaximum * 0.59 and currencyCount < currencyMaximum * 0.79 then
		currencyCountText = "|cFFf6ed12"..currencyCount
	elseif currencyCount > currencyMaximum * 0.79 then
		currencyCountText = "|cFFFF2e2e"..currencyCount
	else
		currencyCountText = TitanUtils_GetHighlightText(currencyCount)
	end

	local BarBalanceText = ""
	if currencyMaximum and TitanGetVar(ID, "ShowBarBalance") then
		if (currencyCount - startcurrency) > 0 then
			BarBalanceText = " |cFF69FF69["..(currencyCount - startcurrency).."]"
		elseif (currencyCount - startcurrency) < 0 then
			BarBalanceText = " |cFFFF2e2e["..(currencyCount - startcurrency).."]"
		end
	end

	return L["ConquestLabel"], currencyCountText..BarBalanceText
end
-----------------------------------------------
local function GetTooltipText(self, id)
	local ColorValueAccount = "0" -- Cores da conta de valor
	if currencyCount and startcurrency then
		local dif = currencyCount - startcurrency
		if dif == 0 then
			ColorValueAccount = TitanUtils_GetHighlightText("0")
		elseif dif > 0 then
			ColorValueAccount = "|cFF69FF69"..dif
		else
			ColorValueAccount = "|cFFFF2e2e"..dif
		end
	end

	local valorAtual = TitanUtils_GetHighlightText(Util_StringComDefault(currencyCount, "0"))
	local valorMaximo = TitanUtils_GetHighlightText(Util_StringComDefault(currencyMaximum, "0"))

	local ValueText = "" -- Difere com e sem moeda
	if currencyCount == 0 then
		ValueText = "|cFFFF2e2e"..L["NoConquest"]
	else
		ValueText = L["tooltipCountMaxLabel"]..valorAtual.." / "..valorMaximo.."\r"..L["session"]..ColorValueAccount
	end

	return L["ConquestDescription"].."\r\r"..ValueText
end
-----------------------------------------------
L.Elib({
	id = ID,
	name = "Titan|cFF007edd "..L["ConquestTitle"].."|r",
	tooltip = L["ConquestTitle"],
	icon = ICON,
	category = "Information",
	version = version,
	getButtonText = GetButtonText,
	getTooltipText = GetTooltipText,
	eventsTable = eventsTable,
	prepareMenu = L.PrepareCurrenciesMenu,
	savedVariables = {
		ShowIcon = 1,
		DisplayOnRightSide = false,
		ShowBarBalance = false,
		ShowLabelText = false,
	}
})
